/*
 * radar.h
 *
 *  Created on: 21/05/2014
 *      Author: yan
 */

#ifndef RADAR_H_
#define RADAR_H_
#include "inc.h"
#include "util.h"

struct Target
{
	double range = -1.0;	// m
	double velocity = -1.0; // m/s
	double SNR = -1.0;	  // Sound to noise ratio (unit noise power assumed)

	bool operator<(Target &rhs);
};

/*
 * Generates a chirp signal using the given parameters.
 */
extern valarray<complex<double>> chirp_signal(double T, double W, double p);

class radar
/* Make pulse Doppler radar data
 * + velocity in meters/sec, distance in m, times in sec, BW in Hz
 * + assumes each pulse is constant (complex) amplitude
 * + will accommodate up to quadratic phase pulses
 * + allows distributed targets
 */
{
public:
	valarray<complex<double>> chirp;  //baseband single pulse waveform
	double chirp_sampling_rate;		  // sampling frequency of input pulse, Hz
	vector<double> pulse_start_times; // start time(s) of input pulse(s), sec
									  // number of pulses in burst assumed = length(g)
	vector<double> gains;			  //complex gain(s) of pulse(s)
	vector<double> start_and_end;	  // 2-vector [T_min, T_max] defines output window delay
									  // times w.r.t start of pulse
	double T_ref = 0.0;				  // system "reference" time
	double fc;						  // center frequency of the radar
	vector<Target> targets;			  // vector of targets
	int pulse_number;				  // Number of pulses
	double pulse_length;			  // pulse lengths in seconds
	double chirp_bandwidth;			  // bandwidth in hz
	double PRF;						  // Pulse repition frequency (pulses / second)

	void setup(istream& infile);
	void print_to_file(ostream &outfile);
	vector<valarray<complex<double>>> simulate();
	void add_noise(vector<valarray<complex<double>>> &y);
};

#endif /* RADAR_H_ */
