#include "inc.h"
#include "graph.h"
#include "radar.h"
#include "util.h"

void print_matrix_to_file(ostream &outfile, const vector<valarray<complex<double>>> &signal_matrix)
{
    // Print out dimensions
    outfile << signal_matrix.size() << " " << signal_matrix[0].size() << "\n";

    for (size_t i = 0; i < signal_matrix.size(); ++i)
    {
        for (size_t j = 0; j < signal_matrix[i].size(); ++j)
        {
            outfile << signal_matrix[i][j].real() << " " << signal_matrix[i][j].imag() << " ";
        }

        outfile << "\n";
    }
}

/*
* Create the simulated pulse signals and create a plot with the generated
* signals. y becomes a matrix that contains the place scaled, range-delayed,
* Doppler shifted pulse.
*/
void get_radar_signal(radar &a_radar, vector<valarray<complex<double>>> &signal_matrix)
{
    signal_matrix = a_radar.simulate();

#ifdef GENPLOT
    simulate_signal_plot(a_radar, signal_matrix);
#endif
}

int main(int argc, char **argv)
{
    if (argc > 3 || argc < 2)
    {
        cerr << "Usage: ./signal [input filename] [optional: output filename]\n";
        return 0;
    }

    // Input file that we will read test information from
    ifstream infile(argv[1]);
    if (!infile.is_open()) {
		cerr << "Input file cannot be found.\n";
		return 1;
	}

    // Output file that we will print out information to.
    ofstream outfile((argc == 2) ? "signal_matrix.out" : argv[2]);

    radar a_radar;
    a_radar.setup(infile);
    infile.close();
    a_radar.print_to_file(outfile);

    // Generate and print signal matrix to the file.
    vector<valarray<complex<double>>> signal_matrix;
    get_radar_signal(a_radar, signal_matrix);
    print_matrix_to_file(outfile, signal_matrix);
    outfile.close();
}